@@ -1,11 +1,17 @@
 from IPython.display import HTML
+from pydantic import Field
 
 from nbprint import Content
 
 __all__ = (
     "ExampleFinanceAuthor",
+    "ExampleFinanceBulletPoints",
     "ExampleFinanceDisclosures",
+    "ExampleFinanceFinancialTable",
     "ExampleFinanceFirstPageDisclosures",
+    "ExampleFinanceKeyMetricsTable",
+    "ExampleFinanceSectionHeading",
+    "ExampleFinanceSectionText",
     "ExampleFinanceStockBody",
     "ExampleFinanceStockEarningsTable",
     "ExampleFinanceStockHeadline",
@@ -14,6 +20,7 @@ __all__ = (
     "ExampleFinanceStockSubHeadline",
     "ExampleFinanceStockWhatsChanged",
     "ExampleFinanceTitle",
+    "ExampleFinanceValuationTable",
 )
 
 
@@ -522,3 +529,404 @@ Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor i
 Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.
 </p>
         """)
+
+
+class ExampleFinanceSectionHeading(Content):
+    title: str = ""
+    color: str = "#5db39c"
+
+    css: str = """
+:scope {
+  margin-top: 25px;
+  margin-bottom: 15px;
+  page-break-after: avoid;
+}
+
+h2 {
+  font-size: 18px;
+  font-weight: bold;
+  margin: 0px !important;
+  padding: 8px 0px;
+}
+"""
+
+    def __call__(self, ctx=None, *args, **kwargs):
+        return HTML(f"""
+        <div style="border-left: 4px solid {self.color}; padding-left: 10px;">
+            <h2>{self.title}</h2>
+        </div>
+        """)
+
+
+class ExampleFinanceSectionText(Content):
+    text: str = ""
+
+    css: str = """
+:scope p {
+  font-size: 11px;
+  line-height: 1.5;
+  margin-bottom: 10px;
+  text-align: justify;
+}
+"""
+
+    def __call__(self, ctx=None, *args, **kwargs):
+        return HTML(f"<p>{self.text}</p>")
+
+
+class ExampleFinanceFinancialTable(Content):
+    css: str = """
+:scope {
+  margin: 15px 0px;
+  break-inside: avoid;
+}
+
+table {
+  width: 100%;
+  border-collapse: collapse;
+  font-size: 10px;
+}
+
+table thead {
+  background-color: #f5f5f5;
+  font-weight: bold;
+}
+
+table thead tr th {
+  padding: 8px 5px;
+  text-align: right;
+  border-bottom: 2px solid #333;
+}
+
+table thead tr th:first-child {
+  text-align: left;
+}
+
+table tbody tr td {
+  padding: 6px 5px;
+  text-align: right;
+  border-bottom: 1px solid #ddd;
+}
+
+table tbody tr td:first-child {
+  text-align: left;
+  font-weight: 500;
+}
+
+table tbody tr.total td {
+  font-weight: bold;
+  border-top: 2px solid #333;
+  border-bottom: 2px solid #333;
+}
+"""
+
+    def __call__(self, ctx=None, *args, **kwargs):
+        return HTML("""
+            <table>
+                <thead>
+                    <tr>
+                        <th>Income Statement ($mm)</th>
+                        <th>FY2023A</th>
+                        <th>FY2024E</th>
+                        <th>FY2025E</th>
+                        <th>FY2026E</th>
+                    </tr>
+                </thead>
+                <tbody>
+                    <tr>
+                        <td>Revenue</td>
+                        <td>12,450</td>
+                        <td>14,120</td>
+                        <td>16,340</td>
+                        <td>18,720</td>
+                    </tr>
+                    <tr>
+                        <td>Cost of Revenue</td>
+                        <td>(7,890)</td>
+                        <td>(8,950)</td>
+                        <td>(10,250)</td>
+                        <td>(11,680)</td>
+                    </tr>
+                    <tr>
+                        <td>Gross Profit</td>
+                        <td>4,560</td>
+                        <td>5,170</td>
+                        <td>6,090</td>
+                        <td>7,040</td>
+                    </tr>
+                    <tr>
+                        <td>Operating Expenses</td>
+                        <td>(3,240)</td>
+                        <td>(3,650)</td>
+                        <td>(4,180)</td>
+                        <td>(4,730)</td>
+                    </tr>
+                    <tr>
+                        <td>EBITDA</td>
+                        <td>1,820</td>
+                        <td>2,120</td>
+                        <td>2,560</td>
+                        <td>3,010</td>
+                    </tr>
+                    <tr>
+                        <td>Depreciation & Amortization</td>
+                        <td>(500)</td>
+                        <td>(580)</td>
+                        <td>(670)</td>
+                        <td>(760)</td>
+                    </tr>
+                    <tr>
+                        <td>EBIT</td>
+                        <td>1,320</td>
+                        <td>1,540</td>
+                        <td>1,890</td>
+                        <td>2,250</td>
+                    </tr>
+                    <tr>
+                        <td>Interest Expense</td>
+                        <td>(180)</td>
+                        <td>(210)</td>
+                        <td>(230)</td>
+                        <td>(250)</td>
+                    </tr>
+                    <tr>
+                        <td>Pre-Tax Income</td>
+                        <td>1,140</td>
+                        <td>1,330</td>
+                        <td>1,660</td>
+                        <td>2,000</td>
+                    </tr>
+                    <tr>
+                        <td>Taxes</td>
+                        <td>(285)</td>
+                        <td>(333)</td>
+                        <td>(415)</td>
+                        <td>(500)</td>
+                    </tr>
+                    <tr class="total">
+                        <td>Net Income</td>
+                        <td>855</td>
+                        <td>997</td>
+                        <td>1,245</td>
+                        <td>1,500</td>
+                    </tr>
+                </tbody>
+            </table>
+        """)
+
+
+class ExampleFinanceValuationTable(Content):
+    color: str = "#5db39c"
+
+    css: str = """
+:scope {
+  margin: 15px 0px;
+  break-inside: avoid;
+}
+
+table {
+  width: 100%;
+  border-collapse: collapse;
+  font-size: 10px;
+}
+
+table thead {
+  font-weight: bold;
+}
+
+table thead tr th {
+  padding: 8px 5px;
+  text-align: right;
+  border-bottom: 2px solid #333;
+}
+
+table thead tr th:first-child {
+  text-align: left;
+}
+
+table tbody tr td {
+  padding: 6px 5px;
+  text-align: right;
+  border-bottom: 1px solid #ddd;
+}
+
+table tbody tr td:first-child {
+  text-align: left;
+}
+
+table tbody tr.highlight td {
+  font-weight: bold;
+}
+"""
+
+    def __call__(self, ctx=None, *args, **kwargs):
+        return HTML(f"""
+            <table>
+                <thead>
+                    <tr>
+                        <th>Valuation Methodology</th>
+                        <th>Multiple</th>
+                        <th>Value per Share</th>
+                        <th>Weight</th>
+                        <th>Weighted Value</th>
+                    </tr>
+                </thead>
+                <tbody>
+                    <tr>
+                        <td>P/E Multiple (FY25E)</td>
+                        <td>12.5x</td>
+                        <td>$11.25</td>
+                        <td>40%</td>
+                        <td>$4.50</td>
+                    </tr>
+                    <tr>
+                        <td>EV/EBITDA Multiple (FY25E)</td>
+                        <td>8.5x</td>
+                        <td>$10.50</td>
+                        <td>30%</td>
+                        <td>$3.15</td>
+                    </tr>
+                    <tr>
+                        <td>DCF Valuation</td>
+                        <td>-</td>
+                        <td>$9.00</td>
+                        <td>30%</td>
+                        <td>$2.70</td>
+                    </tr>
+                    <tr class="highlight" style="background-color: {self.color}15;">
+                        <td><strong>Blended Target Price</strong></td>
+                        <td>-</td>
+                        <td>-</td>
+                        <td>100%</td>
+                        <td><strong>$10.35</strong></td>
+                    </tr>
+                </tbody>
+            </table>
+        """)
+
+
+class ExampleFinanceKeyMetricsTable(Content):
+    css: str = """
+:scope {
+  margin: 15px 0px;
+  break-inside: avoid;
+}
+
+table {
+  width: 100%;
+  border-collapse: collapse;
+  font-size: 10px;
+}
+
+table thead {
+  background-color: #f5f5f5;
+  font-weight: bold;
+}
+
+table thead tr th {
+  padding: 8px 5px;
+  text-align: right;
+  border-bottom: 2px solid #333;
+}
+
+table thead tr th:first-child {
+  text-align: left;
+}
+
+table tbody tr td {
+  padding: 6px 5px;
+  text-align: right;
+  border-bottom: 1px solid #ddd;
+}
+
+table tbody tr td:first-child {
+  text-align: left;
+}
+"""
+
+    def __call__(self, ctx=None, *args, **kwargs):
+        return HTML("""
+            <table>
+                <thead>
+                    <tr>
+                        <th>Key Operating Metrics</th>
+                        <th>FY2023A</th>
+                        <th>FY2024E</th>
+                        <th>FY2025E</th>
+                        <th>FY2026E</th>
+                    </tr>
+                </thead>
+                <tbody>
+                    <tr>
+                        <td>Revenue Growth (YoY)</td>
+                        <td>18.5%</td>
+                        <td>13.4%</td>
+                        <td>15.7%</td>
+                        <td>14.6%</td>
+                    </tr>
+                    <tr>
+                        <td>Gross Margin</td>
+                        <td>36.6%</td>
+                        <td>36.6%</td>
+                        <td>37.3%</td>
+                        <td>37.6%</td>
+                    </tr>
+                    <tr>
+                        <td>EBITDA Margin</td>
+                        <td>14.6%</td>
+                        <td>15.0%</td>
+                        <td>15.7%</td>
+                        <td>16.1%</td>
+                    </tr>
+                    <tr>
+                        <td>Operating Margin</td>
+                        <td>10.6%</td>
+                        <td>10.9%</td>
+                        <td>11.6%</td>
+                        <td>12.0%</td>
+                    </tr>
+                    <tr>
+                        <td>Net Margin</td>
+                        <td>6.9%</td>
+                        <td>7.1%</td>
+                        <td>7.6%</td>
+                        <td>8.0%</td>
+                    </tr>
+                    <tr>
+                        <td>ROE</td>
+                        <td>15.2%</td>
+                        <td>16.8%</td>
+                        <td>18.9%</td>
+                        <td>20.5%</td>
+                    </tr>
+                    <tr>
+                        <td>ROIC</td>
+                        <td>12.8%</td>
+                        <td>14.1%</td>
+                        <td>15.6%</td>
+                        <td>17.0%</td>
+                    </tr>
+                </tbody>
+            </table>
+        """)
+
+
+class ExampleFinanceBulletPoints(Content):
+    items: list[str] = Field(default_factory=list)
+
+    css: str = """
+:scope ul {
+  font-size: 11px;
+  line-height: 1.6;
+  margin: 10px 0px;
+  padding-left: 20px;
+}
+
+:scope ul li {
+  margin-bottom: 8px;
+}
+"""
+
+    def __call__(self, ctx=None, *args, **kwargs):
+        items_html = "".join([f"<li>{item}</li>" for item in self.items])
+        return HTML(f"<ul>{items_html}</ul>")
